
void set_calibration(int n)
{
  int cal_frequency[7] = {900,1900,2200,3600,5800,8000,2200}; //
  float cal_slope[7] = {-0.0245, -0.0244, -0.0244, -0.0243, -0.0243, -0.030, -0.0244}; // in V/db
  float cal_intercept[7] = {22.0, 20.4, 19.6, 19.8, 25.0, 37.0, 19.6}; // in dBm
  int onedb_err_limit_high[7] = {-1,-5,-4,-3,0,0,-4};  // 1 db error limits
  int onedb_err_limit_low[7] = {-55,-68,-60,-52,-56,-54,-60};
  if(n>0 && n<8){
    n=n-1; // array starts at 0
    frequency = cal_frequency[n];
    //strcpy(calibration_freq, cal_freq_str[n]);
    slope = cal_slope[n];
    intercept = cal_intercept[n];
    
    eeprom_cal = read_EEPROM(n);
    slopeStr = "Slope "+ String(slope*1000,1) + " mV/dBm";
    interceptStr = "Intercept " + String(intercept,1) + " dBm";
    err_limit_high = onedb_err_limit_high[n];
    err_limit_low = onedb_err_limit_low[n];
    }
  else return;
}

// -----------------------------------------------------------------------------------------------------
float read_AD8318(int an_pin)                       // returns average of 10 readings from analog pin
{
  byte i;
  int inp_adc;                                      // result from adc stored here (max 10230 if 10 repeats)
  float adcAverage;
  inp_adc  =  analogRead(an_pin);                   // discard first AD conversion
  inp_adc  =  0;                                    // clear result
  for(i=0; i<10; i++) {                             // read 10 times     
      inp_adc  =  inp_adc + analogRead(an_pin);     // sum results
  }
  adcAverage = float(inp_adc)/10;                   // divide by 10 to get average
  adcAverage = adcAverage*vRef/1023.0;              // convert to voltage with respect to reference 
  return adcAverage;
}  

// -----------------------------------------------------------------------------------------------------
void volt_to_Power(float volt_PwrMeter)             // convert voltage from powermeter to db and string
{ 
  pwr_mVStr = String(volt_PwrMeter,3) + " V";
  pwr = volt_PwrMeter/slope + intercept; // main power function pwr in dB
  pwr_mW = pow(10,pwr/10); //power in mW
  pwrStr = String(pwr,1) + " dB";
  if(pwr_mW < 0.010)
    pwr_mWStr = String(pwr_mW*1000,3) + " uW";
  else 
    pwr_mWStr = String(pwr_mW,3) + " mW";
}

// -----------------------------------------------------------------------------------------------------
void get_power(int dpin)                  // get RF power and convert to strings for HTML
{ 
  digitalWrite(dpin, HIGH); // chose the correct AD8318
  voltage_PwrMeter = read_AD8318(A0);
  volt_to_Power(voltage_PwrMeter);
  digitalWrite(dpin, LOW); // switch off
}

// -----------------------------------------------------------------------------------------------------
void calculate_ReturnLoss_and_SWR()
{   
  float RL_linear, Return_Loss;
  
  Return_Loss = pwr0 - pwr;    
  RL_linear = pow(10,Return_Loss/20 );
  vswr = (RL_linear+1)/(RL_linear-1);
  vswrStr = String(vswr,1);
  DPRINTLN("VSWR " + vswrStr);
}

// -----------------------------------------------------------------------------------------------------
void calculate_slope_intercept(float p1, float p2, float v1, float v2)
{
  // assumes p2>p1
  // p1 en p2 in dB, v1 en v2 in volt
 
  slope = (v2-v1)/(p2-p1);   // in dBm/V
  intercept = p2-(v2/slope); // in dBm
  

  
}
