// -----------------------------------------------------------------------------------------------------
void send_response(WiFiClient client)
{
  // HTTP headers always start with a response code (e.g. HTTP/1.1 200 OK)
  // and a content-type so the client knows what's coming, then a blank line:
  client.println("HTTP/1.1 200 OK");
  client.println("Content-type:text/html");
  client.println("Connection: close");
  client.println();
}

// -----------------------------------------------------------------------------------------------------
void send_Heading(WiFiClient client)
{
  client.println("<!DOCTYPE html><html>");
  client.println("<head><meta name=\"viewport\" content=\"width=device-width, initial-scale=1\">");
  client.println("<title>AD8318 Power Meter</title>");
  if(autorefresh_rate>0 && state=="measure"){
    String autorefreshStr=String(autorefresh_rate);
    client.println("<meta http-equiv='refresh' content='"+autorefreshStr+"'/>"); // autorefresh in seconds
  }
  //client.println("<link rel=\"icon\" href=\"data:,\">"); // prevent favicon requests
  client.println("<link rel=\"icon\" type=\"image/png\" href=\"data:;base64,iVBORw0KGgo=\">"); // prevent favicon requests
  //see: https://stackoverflow.com/questions/1321878/how-to-prevent-favicon-ico-requests
  client.println("<script type=\"text/javascript\"></script>");
}

// -----------------------------------------------------------------------------------------------------
void send_CSS(WiFiClient client)   // send CSS  Style Sheet
{
  client.println("<style>html { font-family: Helvetica; display: inline-block; margin: 0px auto; text-align: center;}");
  client.println(".button { background-color: #676869; border: none; color: white; padding: 16px 40px;");
  client.println("text-decoration: none; font-size: 30px; margin: 2px; cursor: pointer;}");
  client.println(".button2 {background-color: #0974DF;}");
  client.println("a:link {text-decoration: none;}");
  client.println("a:hover:not(.active) {color: black;}");
  client.println(".w3-sidebar{height:100%;width:33.333%;background-color:#fff;overflow:auto;padding:0 0px;right:0px;}");
  client.println(".w3-topbar{width:100%;background-color:#0478e5;color:white;overflow:auto;padding:0 0px;margin:0px;}");
  client.println(".w3-bottombar{width:100%;background-color:#0478e5;color:white;overflow:auto;padding:20px 0px;right:0px;margin-top 10px;}");
  client.println(".w3-twothird{height:100%;width:66.666%;padding:0 8px;margin:0px;}");
  client.println(".resultbox{text-align:center;background-color:#e5bc04;color:042de5;font-size:30px;padding:20px 0px}");
  client.println(".w3-shadow{box-shadow:0 2px 5px 0 rgba(0,0,0,0.16),0 2px 10px 0 rgba(0,0,0,0.12);}");
  client.println("ul {list-style-type: none;margin: 0;padding: 0;background-color: #f1f1f1;border: 1px solid #555;}");
  client.println("li a {display: block;color: #000;padding: 8px 8px;text-decoration: none;font-size: 20px;}");
  client.println("li {text-align: center;border-bottom: 1px solid #555;}li:last-child {border-bottom: none;}");
  client.println("li a.active {background-color: #0478e5;color: white;}");
  client.println("li a:hover:not(.active) {background-color: #555;color: white;}");
  client.println(".clearfix::after {content:"";clear:both;display:table;}");
  client.println(".clearfix {overflow:auto;}");
  client.println("</style></head>");
}

// -----------------------------------------------------------------------------------------------------
void send_Body_Heading(WiFiClient client)
{
  client.println("<body>");
  client.println("<div id=\"top_div\" class=w3-topbar><h1>ESP8266 AD8318 Power Meter</h1>");
  client.println("<h3>0.001 to 8.0 GHz, -55 to -5 dB</h3></div>");
}

// -----------------------------------------------------------------------------------------------------
void send_Resultbox(WiFiClient client)
{
  client.println("<div class=\"clearfix\" style=\"background-color:#e5bc04\">");// end </div> in send_Freq_Select_Sidebar()
  client.println("<div id=\"resultbox\" class=\"w3-twothird resultbox\" style = display:inline-block>");
  if(state=="measure"){
    get_power(D0);
    pwr0=pwr;
    DPRINTLN("pwrStr: "+pwrStr+ " en pwr_mVStr:" + pwr_mWStr+ " van send_Resultbox ");
    client.println(pwrStr+"<br><span style=\"font-size:20px\">" + pwr_mWStr+"</span><br>");
    if(dual_AD8318){
      get_power(D1);
      client.println("<br>"+ pwrStr+"<br><span style=\"font-size:20px\">" + pwr_mWStr+"</span><br>");
      calculate_ReturnLoss_and_SWR();
      client.println("<br>"+ vswrStr+ " vswr" +"<br>");
    }
  }
  else if(state=="calibrate"){
    input_pwr(client);
  }
  client.println("</div>"); // end of div id=\"resultbox\"
}

// -----------------------------------------------------------------------------------------------------
void send_Freq_Select_Sidebar(WiFiClient client)  // side bar div: frequency select buttons
{
  client.println("<div id=\"freq_side_bar\" class=w3-sidebar style=\"float:right;display:inline-block;\" >");  
  client.println("<ul>");
    if(freq_button == 1) buttonStr = "class=\"active\""; else buttonStr = "";
    client.println("<li><a href=\"/1/on\" "+ buttonStr+ "\">0.9 GHz</a></li>");
    if(freq_button == 2) buttonStr = "class=\"active\""; else buttonStr = "";
    client.println("<li><a href=\"/2/on\" "+ buttonStr+ "\">1.7 GHz</a></li>");
    if(freq_button == 3) buttonStr = "class=\"active\""; else buttonStr = "";
    client.println("<li><a href=\"/3/on\" "+ buttonStr+ "\">2.2 GHz</a></li>");
    if(freq_button == 4) buttonStr = "class=\"active\""; else buttonStr = "";
    client.println("<li><a href=\"/4/on\" "+ buttonStr+ "\">3.4 GHz</a></li>");
    if(freq_button == 5) buttonStr = "class=\"active\""; else buttonStr = "";
    client.println("<li><a href=\"/5/on\" "+ buttonStr+ "\">5.8 GHz</a></li>");
    if(freq_button == 6) buttonStr = "class=\"active\""; else buttonStr = "";
    client.println("<li><a href=\"/6/on\" "+ buttonStr+ "\">8.0 GHz</a></li>");
    if(freq_button == 7) buttonStr = "class=\"active\""; else buttonStr = "";
    client.println("<li><a href=\"/7/on\" "+ buttonStr+ "\">User</a></li>");
  client.println("</ul>");
  client.println("</div>"); // end of div id=\"freq_side_bar\" 
  client.println("</div>"); // end of div encompassing div's resultbox and freq_side_bar
}

// -----------------------------------------------------------------------------------------------------
void send_Calibrate_button(WiFiClient client)  // footer for access to calibration page
{
  client.println("<div id=\"calibrate_button\" class=w3-bottombar><a href=\"/Cal\"><h1 style=\"color:white;\">Calibration</h1></a></div>");
}

// -----------------------------------------------------------------------------------------------------
void send_voltages(WiFiClient client)
{
  client.println("<div class=\"clearfix\" style=\"background-color:#e5bc04\">");
  client.println("<div id=\"resultbox\" class=\"w3-twothird resultbox\" style = \"display:inline-block\">");
  get_power(D0);
  pwr1=pwr; 
  client.println(pwrStr+"<br><span style=\"font-size:20px\">" + pwr_mVStr+"</span><br>");
  if(dual_AD8318){
  get_power(D1);
  client.println("<br>"+ pwrStr+"<br><span style=\"font-size:20px\">" + pwr_mVStr+"</span><br>");
  }
  client.println("<br<span style=\"font-size:20px\">"+ slopeStr+"<br>" + interceptStr+"</span><br>");
  client.println("</div>"); // end of div id=\"resultbox\"
}
// -----------------------------------------------------------------------------------------------------
void input_frequency(WiFiClient client)
{
  client.println("<form action=\"/action_page.php\" style=\"font-size:20px\">");
  client.println("<p>Select frequency:</p>");
  client.println("<input type=\"radio\" id=\"0.9 GHz\" name=\"frequency\" value=\"0.9\"><label for=\"0.9 GHz\">0.9 GHz</label><br>");
  client.println("<input type=\"radio\" id=\"1.7 GHz\" name=\"frequency\" value=\"1.7\"><label for=\"1.7 GHz\">1.7 GHz</label><br>");
  client.println("<input type=\"radio\" id=\"2.2 GHz\" name=\"frequency\" value=\"2.2\"><label for=\"2.2 GHz\">2.2 GHz</label><br>");
  client.println("<input type=\"radio\" id=\"3.4 GHz\" name=\"frequency\" value=\"3.4\"><label for=\"3.4 GHz\">3.4 GHz</label><br>");
  client.println("<input type=\"radio\" id=\"5.8 GHz\" name=\"frequency\" value=\"5.8\"><label for=\"5.8 GHz\">5.8 GHz</label><br>");
  client.println("<input type=\"radio\" id=\"8.0 GHz\" name=\"frequency\" value=\"8.0\"><label for=\"8.0 GHz\">8.0 GHz</label><br>");
  client.println("<input type=\"radio\" id=\"user\" name=\"frequency\" value=\"user\"><label for=\"user\">user  </label><br>");
  client.println("<input type=\"submit\" value=\"OK\"></form>");

}

// -----------------------------------------------------------------------------------------------------
void input_pwr(WiFiClient client)
{
  String minStr, maxStr, pwrinStr, pwrinLabel;
  //client.println("<label for=\"pwrinlow\">Power (between -55 and -35):</label>");
  //client.println("<input type=\"range\" id=\"pwrinlow\" name=\"pwrinlow\" min=\"-55\" max=\"-35\">"); 
  /*
<style>
.slidecontainer {
  width: 100%;
}

.slider {
  -webkit-appearance: none;
  width: 100%;
  height: 25px;
  background: #d3d3d3;
  outline: none;
  opacity: 0.7;
  -webkit-transition: .2s;
  transition: opacity .2s;
}

.slider:hover {
  opacity: 1;
}

.slider::-webkit-slider-thumb {
  -webkit-appearance: none;
  appearance: none;
  width: 25px;
  height: 25px;
  background: #4CAF50;
  cursor: pointer;
}

.slider::-moz-range-thumb {
  width: 25px;
  height: 25px;
  background: #4CAF50;
  cursor: pointer;
}
</style>
  // client.println("document.getElementById(\"myDiv\").innerHtml = \"Your new html code to display\"");

  */
  if(calPwr=="LOW"){
    pwrinStr= String(pwrin1);
    get_power(D0);
    calvolt1=voltage_PwrMeter; //from get_power()
    minStr = String("-55");
    maxStr = String("-35");
    pwrinLabel = "Power in LOW: ";
  }
  if(calPwr=="HIGH"){
    pwrinStr= String(pwrin2);
    get_power(D0);  // still on first input, now high pwr
    calvolt2=voltage_PwrMeter; //from get_power()
    minStr = String("-25");
    maxStr = String("-5");
    pwrinLabel = "Power in HIGH: ";
  }
  client.println("<div class=\"slidecontainer\" width=\"70%\" margin-left=\"0px\" style=\"font-size:20px\">");
  client.println("<form action=\"/powercal_page.php\">");
  client.println("<p>"+pwrinLabel+"<span id=\"pwrIn\"></span></p>");
  client.println("<input type=\"range\" id=\"pwrRange\" step=\"0.1\" min=\""+minStr+"\" max=\""+maxStr+"\" value=\""+pwrinStr+"\" class=\"slider\" name=\"pwrIn\">");  
  client.println("<p><span style=\"font-size:20px\"<br>Input 0: "+pwr_mVStr+"<br></span></p>");
  client.println("<input type=\"submit\" value=\"Redo\" name=\"command\" style=\"font-size:20px\">");
  client.println("<input type=\"submit\" value=\"Accept\" name=\"command\"style=\"font-size:20px\"></form></div>");
  send_slider_script(client);
}
// -----------------------------------------------------------------------------------------------------
void send_accept_cal(WiFiClient client){
  String strcalpwr1, strcalvolt1, strcalpwr2, strcalvolt2;
  String interceptStr, slopeStr;

  strcalpwr1 = "Pwr low  " + String(calpwr1,1) + " dBm "; // 1 decimal 
  strcalpwr2 = "Pwr high " + String(calpwr2,1) + " dBm ";
  strcalvolt1 = String(calvolt1,1) + " V";
  strcalvolt2 = String(calvolt2,1) + "V";
  interceptStr="Intercept " + String(intercept,1) + " dbm";
  slopeStr="Slope " + String(slope*1000,1)+ " mV/dBm" ;
  
  
  client.println("<div class=\"clearfix\" style=\"background-color:#e5bc04;font-size:20px;line-height:25px;\">");// end </div> in send_Freq_Select_Sidebar()
  client.println("<div id=\"resultbox\" class=\"w3-twothird resultbox\" style = display:inline-block>");
  client.println("<span style=\"font-size:20px;line-height:25px;\">Calibration input<br>");
  client.println(strcalpwr1 + strcalvolt1 + "<br>" + strcalpwr2 + strcalvolt2 + "<br></span>");

  client.println("<div style=\"border:10px solid #e5bc04;padding:10px;background-color:#CDE6FE;font-size:24px;\">");
  client.println("<span>Calibration result<br>" + slopeStr + "<br>"+interceptStr + "</span></div>");
  client.println("<form action=\"/powercal_page.php\"><input type=\"submit\" value=\"Store\" name=\"command\" style=\"font-size:20px\"> ");
  client.println("<input type=\"submit\" value=\"Temp\" name=\"command\" style=\"font-size:20px\">"); 
  client.println("<input type=\"submit\" value=\"Erase\" name=\"command\" style=\"font-size:20px\"></form>"); 

  client.println("</div>"); // end of div id=\"resultbox\"
}

// -----------------------------------------------------------------------------------------------------
void send_slider_script(WiFiClient client)
{
  client.println("<script>");
  client.println("var slider = document.getElementById(\"pwrRange\");");
  client.println("var output = document.getElementById(\"pwrIn\");");
  client.println("output.innerHTML = slider.value;");  
  client.println("slider.oninput = function() {output.innerHTML = this.value;}</script>");
}

// -----------------------------------------------------------------------------------------------------
void send_end_tags(WiFiClient client)
{
  client.println("</body></html>");   // end tags
  client.println();                   // The HTTP response ends with another blank line
}
