/*********
 * Webserver for NodeMCU-ESP2866-12E V3 with dual AD8318 RF power meter
 * Poll van der Wouw PA3BYV, 25-5-2020
 * 
 * Webserver part is based on an idea from Rui Santos, see https://randomnerdtutorials.com  
 * 
 * This software is free of copyright. Use at your own risk.
 * 
*********/
// make sure you selected the right board before compiling
// otherwise the IDE can not find the correct libraries
//
// Load Wi-Fi library
#include <ESP8266WiFi.h>

// load EEPROM library
#include <EEPROM.h>

// Replace with your network credentials
const char* ssid     = "YOUR-WIFI-NAME";
const char* password = "YOUR-PASSWORD";


// Set web server port number to 80
WiFiServer server(80);


// Variable to store the HTTP request
String header;

// autorefresh rate in seconds, 0=no refresh
int autorefresh_rate = 3;

//Dual or singel AD8318
bool dual_AD8318 = true;  // change to false when single AD8318 is used

// Current time
unsigned long currentTime = millis();
// Previous time
unsigned long previousTime = 0; 
// Define timeout time in milliseconds (example: 2000ms = 2s)
const long timeoutTime = 2000;

// variables to store calibration and frequency
float slope;
float intercept;
int frequency;
float vRef = 2.2; // internal reference voltage is 1 V with a 120K/100K voltage divider before A0
//char calibration_freq[7];
//char *cal_freq_str[] = {"0.9 GHz","1.9 GHz","2.2 GHz","3.6 GHz","5.8 GHz","8.0 GHz","User  "};
int err_limit_high, err_limit_low;
float voltage_PwrMeter;

float pwr, pwr_mW, pwr0, pwr1, pwr2, vswr;
float pwrin1 = -55.0, pwrin2 = -5.0;
String pwrStr, pwr_mWStr, vswrStr, pwr_mVStr, slopeStr, interceptStr ;

int freq_button=1;
String buttonStr;

byte ledstatus = 0;
bool calib = false;
bool eeprom_cal = false;
String state = "measure";
String calPwr = "LOW";
float calpwr1, calvolt1, calpwr2, calvolt2;

#define DEBUG   //If you comment this line, the DPRINT & DPRINTLN lines are defined as blank.
#ifdef DEBUG    //Macros are usually in all capital letters.
  #define DPRINT(...)    Serial.print(__VA_ARGS__)     //DPRINT is a macro, debug print
  #define DPRINTLN(...)  Serial.println(__VA_ARGS__)   //DPRINTLN is a macro, debug print with new line
#else
  #define DPRINT(...)     //now defines a blank line
  #define DPRINTLN(...)   //now defines a blank line
#endif


void setup() {
  Serial.begin(115200); // start serial monitor (only used for debug)
  EEPROM.begin(512); // start EEPROM, reads EEPROM into RAM
  // Set outputs to LOW
  digitalWrite(D0, LOW);
  digitalWrite(D1, LOW);
  // Initialize the output variables as outputs
  pinMode(D0, OUTPUT);
  pinMode(D1, OUTPUT);

  pinMode(LED_BUILTIN, OUTPUT); //led builtin is on GPIO2 (D4) (not on GPIO16, D0)
  digitalWrite(LED_BUILTIN, ledstatus);

  // Connect to Wi-Fi network with SSID and password
  Serial.print("\n\nConnecting to ");
  Serial.println(ssid);
  WiFi.begin(ssid, password);
  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
    ledstatus = ~ledstatus;
    digitalWrite(LED_BUILTIN, ledstatus);
    Serial.print(".");
  }
  ledstatus = 0;
  digitalWrite(LED_BUILTIN, ledstatus);
  // Print local IP address and start web server
  Serial.println("");
  Serial.println("WiFi connected.");
  Serial.println("IP address: ");
  Serial.println(WiFi.localIP());
  server.begin();
}

void loop(){
  char c;
  int n;
  String varReturned;
  WiFiClient client = server.available();   // Listen for incoming clients

  if (client) {                             // If a new client connects,
    DPRINTLN("New Client.");                // print a message out in the serial port
    digitalWrite(LED_BUILTIN, HIGH);
    String currentLine = "";                // make a String to hold incoming data from the client
    currentTime = millis();
    previousTime = currentTime;
    while (client.connected() && currentTime - previousTime <= timeoutTime) { // loop while the client's connected
      currentTime = millis();         
      if (client.available()) {             // if there's bytes to read from the client,
        c = client.read();                  // read a byte, then
        Serial.write(c);                    // print it out the serial monitor
        header += c;
        if (header.length() > 512) break;   // malformed header
        if (c == '\n') {                    // if the byte is a newline character
          // if the current line is blank, you have got two newline characters in a row.
          // that's the end of the client HTTP request, so send a response:
          if (currentLine.length() == 0) 
          { 
            int stringStart = header.indexOf("GET /");
            //freq_button = 1;
            if (stringStart>=0){
              char inChar = header.charAt(stringStart+5);
              if (isDigit(inChar)) {
                n = inChar - '0';           // convert digit-character to integer
                if (n>0 && n<8){
                  freq_button = n; 
                  DPRINT("frequency button = ");  
                  DPRINTLN(freq_button);
                  set_calibration(n);
                  calib = false;
                  state="measure";
                }
              }
              else if(inChar == 'C'){      
                //check referer, if referer is Cal page, toggle between voltages and calibrate
                calib = true;
                if (state=="measure") state="calibrate";               
                else{
                  stringStart = header.indexOf("Referer");
                  if ((header.substring(stringStart)).indexOf("/Cal") > 0){
                    state = (state=="calibrate") ? "voltmode" : "calibrate";
                  }
                }
                DPRINTLN(state);
                DPRINT("frequency button = ");  
                DPRINTLN(freq_button);
              }
              else if(inChar == 'p'){             //powercal_page
                stringStart = header.indexOf("?")+1;
                if (stringStart>=0){
                  int stringEnd = header.indexOf("HTTP") -1;
                  if (stringEnd>stringStart) varReturned = header.substring(stringStart,stringEnd);
                  DPRINT("var returned: ");
                  DPRINTLN(varReturned);
                  if (varReturned.indexOf("pwrIn")==0){
                    String substr1 = varReturned.substring(6);
                    float pwrt=substr1.toFloat();
                    if(pwrt<-34.9)pwrin1=pwrt;
                    else pwrin2=pwrt;
                    //pwrin1 = substr1.toFloat();
                    DPRINT("pwrin1 ");
                    DPRINTLN(pwrin1);
                    DPRINT("pwrin2 ");
                    DPRINTLN(pwrin2);
                  }
                  stringStart = varReturned.indexOf("&");
                  if (stringStart>=0){
                    String substr1 = varReturned.substring(stringStart+1);
                    DPRINT("varReturned substring substr1: ");
                    DPRINTLN(substr1);
                    if(substr1.substring(8)=="Redo"){
                      // just redo calib measurement
                      DPRINTLN("Redo");
                    }
                    if(substr1.substring(8)=="Accept"){
                      if(calPwr == "LOW"){
                        calpwr1 = pwrin1;
                        calvolt1 = voltage_PwrMeter;
                        calPwr = "HIGH";
                      }
                      else if(calPwr == "HIGH"){
                        calpwr2 = pwrin2;
                        calvolt2 = voltage_PwrMeter;
                        calPwr = "LOW";
                        // low and high measured, now calculate slope and intercept
                        calculate_slope_intercept(calpwr1, calpwr2, calvolt1, calvolt2);
                        DPRINT("slope: ");
                        DPRINT(slope);
                        DPRINT(", intercept: ");
                        DPRINTLN(intercept);
                        // calibration measurements completed, display accept calibration page
                        state="cal_ready_for_acceptance";
                        
                      }
                      DPRINT(calPwr);
                      DPRINT(" voltage_PwrMeter: ");
                      DPRINTLN(voltage_PwrMeter);
                      
                    }
                  }
                  if(varReturned.substring(8)=="Store"){
                    bool stored=write_EEPROM(freq_button-1, frequency, slope, intercept);
                    DPRINT("Calibration stored: ");
                    DPRINTLN(stored);
                    state = "measure";
                  }
                  if(varReturned.substring(8)=="Temp"){
                    DPRINTLN("Calibration discarded");
                    state = "measure";
                  }
                  if(varReturned.substring(8)=="Erase"){
                    bool erased = erase_EEPROM(freq_button-1);
                    DPRINT("Calibration erased: ");
                    DPRINTLN(erased);
                    state = "measure";
                  }
                
                }
              }

            }   
            send_response(client);        // HTTP/1.1 200 OK
            send_Heading(client);         // send HTML web page heading     
            send_CSS(client);             // CSS  Style Sheet 
            send_Body_Heading(client);    // Web Page body Heading

            if(state == "voltmode"){
              send_voltages(client);
            }
            if(state=="cal_ready_for_acceptance"){
              send_accept_cal(client);
            }
            if(state=="measure" || state=="calibrate") {
              send_Resultbox(client); // can be measurement or calib mode
            }
            send_Freq_Select_Sidebar(client);  // display frequency calibration curve buttons             
            send_Calibrate_button(client);
            send_slider_script(client);
            send_end_tags(client);

            // Break out of the while loop
            break;
          } 
          else { // if you got a newline, then clear currentLine
            currentLine = "";
          }
        } 
        else if (c != '\r') {  // if you got anything else but a carriage return character,
          currentLine += c;      // add it to the end of the currentLine
        }
      }
    }
    // Clear the header variable
    header = "";
    // Close the connection
    client.stop();
    DPRINTLN("Client disconnected.");
    DPRINTLN("");
    digitalWrite(LED_BUILTIN, LOW);
  }
}
